﻿Public Class DelegateCommand
    Implements ICommand

    Public Delegate Sub ExecuteDelegate(ByVal parameter As Object)
    Public Delegate Function CanExecuteDelegate(ByVal parameter As Object) As Boolean
    Private _execute As ExecuteDelegate
    Private _canExecute As CanExecuteDelegate

    Public Sub New(ByVal execute As ExecuteDelegate,
                   ByVal Optional canExecute As CanExecuteDelegate = Nothing)
        If execute Is Nothing Then
            Throw New ArgumentNullException(NameOf(execute))
        End If
        _execute = execute
        _canExecute = canExecute
    End Sub

    Private Sub Execute(parameter As Object) Implements ICommand.Execute
        _execute(parameter)
    End Sub

    Private Function CanExecute(parameter As Object) As Boolean Implements ICommand.CanExecute
        If _canExecute Is Nothing Then
            Return True
        End If
        Return _canExecute?.Invoke(parameter)
    End Function


    Public Custom Event CanExecuteChanged As EventHandler _
                          Implements ICommand.CanExecuteChanged
        AddHandler(ByVal value As EventHandler)
            AddHandler CommandManager.RequerySuggested, value
        End AddHandler

        RemoveHandler(ByVal value As EventHandler)
            RemoveHandler CommandManager.RequerySuggested, value
        End RemoveHandler

        RaiseEvent(ByVal sender As System.Object,
                   ByVal e As System.EventArgs)
        End RaiseEvent
    End Event
End Class