﻿Imports System.Net.NetworkInformation

Public Class MainWindowViewModel
    Inherits NotifyPropertyBase

    Private _fromValue As String
    Private _toValue As String
    Private _fromCurrency As Currency
    Private _toCurrency As Currency
    Private _status As String

    Public Sub New()
        RefreshCommand = New DelegateCommand(AddressOf OnRefresh, AddressOf OnCanRefresh)
        CloseCommandBinding = New CommandBinding(ApplicationCommands.Close, AddressOf OnClose, AddressOf OnCanClose)
        OnRefresh(Nothing)
    End Sub

    Public Property Currencies As Currencies

    Public Property ToValue As String
        Get
            Return _toValue
        End Get
        Set(ByVal value As String)
            OnPropertyChanged(_toValue, value)
        End Set
    End Property

    Public Property FromValue As String
        Get
            Return _fromValue
        End Get
        Set(ByVal value As String)
            Dim fromValue As Decimal = Nothing
            Dim isDecimal As Boolean = Decimal.TryParse(value, fromValue)
            fromValue = If(isDecimal, fromValue, 0.0D)
            OnPropertyChanged(_fromValue, value)
            If ToCurrency IsNot Nothing Then ToValue = (ToCurrency.Rate * fromValue).ToString()
        End Set
    End Property

    Public Property FromCurrency As Currency
        Get
            Return _fromCurrency
        End Get
        Set(ByVal value As Currency)
            OnPropertyChanged(_fromCurrency, value)
        End Set
    End Property

    Public Property ToCurrency As Currency
        Get
            Return _toCurrency
        End Get
        Set(ByVal value As Currency)
            OnPropertyChanged(_toCurrency, value)
            FromValue = _fromValue
        End Set
    End Property

    Public Property Status As String
        Get
            Return _status
        End Get
        Set(ByVal value As String)
            OnPropertyChanged(_status, value)
        End Set
    End Property

    Public Property RefreshCommand As DelegateCommand
    Public Property CloseCommandBinding As CommandBinding

    Private Function OnCanRefresh(ByVal obj As Object) As Boolean
        Return NetworkInterface.GetIsNetworkAvailable()
    End Function

    Private Sub OnRefresh(ByVal obj As Object)
        Currencies = Currencies.Load()
        FromCurrency = Currencies(0)
        ToCurrency = Currencies(1)
        FromValue = "1"
        Status = $"Währungen für den {Currencies.Date} geladen"
    End Sub

    Private Sub OnClose(ByVal sender As Object, ByVal e As ExecutedRoutedEventArgs)
        Application.Current.Shutdown()
    End Sub

    Private Sub OnCanClose(ByVal sender As Object, ByVal e As CanExecuteRoutedEventArgs)
        e.CanExecute = True
    End Sub
End Class

