﻿Class MainWindow

    Sub New()
        InitializeComponent()
        fontList.ItemsSource = Fonts.SystemFontFamilies.OrderBy(Function(f) f.Source)
        fontList.SelectedIndex = 0
    End Sub

    Private Async Sub OnFontChanged(sender As Object, e As SelectionChangedEventArgs)
        If fontList.SelectedIndex = -1 Then
            Return
        End If

        Await ShowFont(fontList.SelectedItem)
    End Sub

    Private Async Function ShowFont(fontFamily As FontFamily) As Task
        wrapPanel.Children.Clear()

        Dim fromValue = Integer.Parse(fromUnicode.Text)
        Dim toValue = Integer.Parse(toUnicode.Text)

        progressBar.Minimum = fromValue
        progressBar.Maximum = toValue

        Await Task.Run(
        Sub()
            For i = fromValue To toValue
                Me.Dispatcher.Invoke(
                Sub()
                    For Each typeface As Typeface In fontFamily.GetTypefaces()
                        Dim glyph As GlyphTypeface = Nothing

                        If typeface.TryGetGlyphTypeface(glyph) And glyph.CharacterToGlyphMap.ContainsKey(i) Then
                            Dim button = New Button With
                            {
                                .Content = ChrW(i),
                                .FontFamily = fontFamily,
                                .FontSize = sizeOfFont.Value,
                                .Margin = New Thickness(1),
                                .Background = Brushes.Transparent,
                                .BorderBrush = Brushes.Transparent,
                                .ToolTip = $"Unicode: &#x{i:x4};{vbCrLf}Dezimal: {i}"
                            }
                            wrapPanel.Children.Add(button)
                            Exit For
                        End If
                    Next

                    progressBar.Value += 1
                End Sub)
            Next
        End Sub)
        progressBar.Value = 0
        info.Text = $"Anzahl Zeichen: {wrapPanel.Children.Count}"
    End Function

    Private Sub OnFontSizeChanged(sender As Object, e As RoutedPropertyChangedEventArgs(Of Double))
        If wrapPanel Is Nothing Then
            Return
        End If

        For Each button As Button In wrapPanel.Children
            button.FontSize = e.NewValue
        Next
    End Sub

    Private Async Sub OnRefreshCharacters(sender As Object, e As RoutedEventArgs)
        Await ShowFont(fontList.SelectedItem)
    End Sub

    Private Sub OnClose(sender As Object, e As RoutedEventArgs)
        Dim result As MessageBoxResult = MessageBox.Show(
        "Wirklich beenden?",
        "Zeichentabelle",
        MessageBoxButton.YesNo,
        MessageBoxImage.Question)

        If result = MessageBoxResult.Yes Then
            Close()
        End If
    End Sub


End Class
