﻿Imports System.IO
Imports System.Reflection
Imports System.Windows.Ink
Imports Microsoft.Win32

Class MainWindow
    Sub New()
        InitializeComponent()
        Dim propertyInfosColor As PropertyInfo() = GetType(Colors).GetProperties()

        colorList.ItemsSource = propertyInfosColor
        colorList.SelectedIndex = 0
    End Sub

    Private Sub OnSave(sender As Object, e As RoutedEventArgs)
        Dim dialog = New SaveFileDialog() With
                {
                .Filter = "isf Dateien (*.isf)|*.isf"
                }

        If dialog.ShowDialog() = True Then
            Dim tab As TabItem = sketchSheets.SelectedItem
            Dim inkCanvas As InkCanvas = tab.Content

            Using fileStream = New FileStream(dialog.FileName, FileMode.Create)
                inkCanvas.Strokes.Save(fileStream, True)
            End Using

            tab.Header = Path.GetFileNameWithoutExtension(dialog.FileName)
            status.Text = $"{dialog.FileName} gespeichert"
        End If
    End Sub

    Private Sub OnEditingModeChanged(sender As Object, e As SelectionChangedEventArgs)
        If sketchSheets Is Nothing Then
            Return
        End If

        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        Dim comboBox As ComboBox = sender
        Dim element As FrameworkElement = comboBox.SelectedItem
        Dim tag As String = element.Tag

        Dim editingMode As InkCanvasEditingMode = [Enum].Parse(
                            GetType(InkCanvasEditingMode), tag)
        inkCanvas.EditingMode = editingMode
    End Sub

    Private Sub OnBrushSizeChanged(sender As Object, e As RoutedPropertyChangedEventArgs(Of Double))
        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        Dim size As Double = brushSlider.Value

        inkCanvas.DefaultDrawingAttributes.Width = size
        inkCanvas.DefaultDrawingAttributes.Height = size
    End Sub

    Private Sub OnOpen(sender As Object, e As RoutedEventArgs)
        Dim dialog = New OpenFileDialog With
            {
                .Filter = "isf Dateien (*.isf)|*.isf"
            }

        If dialog.ShowDialog() = True Then
            OnNew(Nothing, Nothing)
            Dim tab As TabItem = sketchSheets.SelectedItem
            Dim inkCanvas As InkCanvas = tab.Content

            Using fileStream = New FileStream(dialog.FileName, FileMode.Open)
                inkCanvas.Strokes = New StrokeCollection(fileStream)
            End Using
            tab.Header = Path.GetFileNameWithoutExtension(dialog.FileName)
        End If
    End Sub

    Private Sub OnNew(sender As Object, e As RoutedEventArgs)
        Dim count As Integer = sketchSheets.Items.Count
        sketchSheets.Items.Add(
                New TabItem() With
                {
                    .Header = $"Blatt {count + 1}",
                    .Content = New InkCanvas()
                })
        sketchSheets.SelectedIndex = count
    End Sub


    Private Sub OnClose(sender As Object, e As RoutedEventArgs)
        Close()
    End Sub

    Private Sub OnBrushColorChanged(sender As Object, e As SelectionChangedEventArgs)
        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        Dim propertyInfo As PropertyInfo = colorList.SelectedItem
        Dim color As Color = propertyInfo.GetValue(Nothing, Nothing)

        inkCanvas.DefaultDrawingAttributes.Color = color

        expanderColumns.IsExpanded = False
    End Sub

    Private Sub OnLineShapeChanged(sender As Object, e As SelectionChangedEventArgs)

    End Sub

    Private Sub OnBrushFormChanged(sender As Object, e As SelectionChangedEventArgs)
        If sketchSheets Is Nothing Then
            Return
        End If

        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        Dim comboBox As ComboBox = sender
        Dim element As FrameworkElement = comboBox.SelectedItem
        Dim stylusTip As StylusTip = element.Tag

        inkCanvas.DefaultDrawingAttributes.StylusTip = stylusTip
    End Sub

    Private Sub OnEditMenuOpened(sender As Object, e As RoutedEventArgs)
        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        menuCopy.IsEnabled = inkCanvas.GetSelectedStrokes().Count > 0
        menuCut.IsEnabled = inkCanvas.GetSelectedStrokes().Count > 0
        menuPaste.IsEnabled = inkCanvas.CanPaste()

    End Sub

    Private Sub OnPaste(sender As Object, e As RoutedEventArgs)
        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        inkCanvas.Paste()
    End Sub

    Private Sub OnCopy(sender As Object, e As RoutedEventArgs)
        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        inkCanvas.CopySelection()
    End Sub

    Private Sub OnCut(sender As Object, e As RoutedEventArgs)
        Dim tab As TabItem = sketchSheets.SelectedItem
        Dim inkCanvas As InkCanvas = tab.Content

        inkCanvas.CutSelection()
    End Sub


End Class
